aboutsummaryrefslogtreecommitdiff
path: root/engines/tsage/globals.h
diff options
context:
space:
mode:
Diffstat (limited to 'engines/tsage/globals.h')
-rw-r--r--engines/tsage/globals.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/engines/tsage/globals.h b/engines/tsage/globals.h
index 86ad025339..15f8c0b611 100644
--- a/engines/tsage/globals.h
+++ b/engines/tsage/globals.h
@@ -97,14 +97,14 @@ public:
void dispatchSounds();
};
-extern Globals *_globals;
+extern Globals *g_globals;
-#define GLOBALS (*_globals)
-#define BF_GLOBALS (*((::TsAGE::BlueForce::BlueForceGlobals *)_globals))
+#define GLOBALS (*g_globals)
+#define BF_GLOBALS (*((::TsAGE::BlueForce::BlueForceGlobals *)g_globals))
-// Note: Currently this can't be part of the _globals structure, since it needs to be constructed
+// Note: Currently this can't be part of the g_globals structure, since it needs to be constructed
// prior to many of the fields in Globals execute their constructors
-extern ResourceManager *_resourceManager;
+extern ResourceManager *g_resourceManager;
namespace BlueForce {